@@ -28,18 +28,18 @@ def volatilidade(__ticker, **kwargs):
 
     try:
         __periodo = [int(kwargs.get('periodo'))]
-        if '|1|3|6|12|'.find('|'+str([__periodo])+'|') == -1:
+        if '|1|3|6|12|'.find('|'+str(__periodo[0])+'|') == -1:
             __periodo = [6]
     except:
         __periodo = [1,3,6,12]
     __result = []
     for __item in __periodo:
-        if __periodo == 1:
-            __periodo_text = '12Meses'
-        elif __periodo == 12:
-            __periodo_text = '1Ano'
+        if __item == 1:
+            __periodo_txt = '1Mes'
+        elif __item == 12:
+            __periodo_txt = '1Ano'
         else:
-            __periodo_txt = str(__periodo) + 'Meses'
+            __periodo_txt = str(__item) + 'Meses'
         # noinspection SpellCheckingInspection
         url = 'http://bvmf.bmfbovespa.com.br/cias-listadas/volatilidade-ativos/ResumoVolatilidadeAtivos.aspx?' \
               'metodo=padrao&' \
